==> haskell-wai-extra-3.1.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-extra
version:              3.1.2
visibility:           public
id:                   wai-extra-3.1.2-1DwW0aM2qbD1iXq8jeMPTK
key:                  wai-extra-3.1.2-1DwW0aM2qbD1iXq8jeMPTK
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  2feb877df432965342446d6e6bdcf640
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:       Network.Wai.Middleware.RequestLogger.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/wai-extra-3.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/wai-extra-3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/wai-extra-3.1.2
hs-libraries:         HSwai-extra-3.1.2-1DwW0aM2qbD1iXq8jeMPTK
depends:
    HUnit-1.6.1.0-Bm5MBgMTtXH6izBDmXcPBY
    aeson-1.5.4.1-L4blGMy4f2B3cvSeFwSnLz
    ansi-terminal-0.11-9pYxsmg45rS4xxti1sPCFD base-4.14.1.0
    base64-bytestring-1.2.0.1-B2ZqPQ2l7aS69MXBYqVZV1
    bytestring-0.10.10.0 call-stack-0.2.0-8H31opUaC4i2upDsk10FSt
    case-insensitive-1.2.1.0-67UnwAOqbT8BnKxqPm1bDl containers-0.6.2.1
    cookie-0.4.5-9B2dS5wCPmq3hZq3aUzZ9g
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 deepseq-1.4.4.0
    directory-1.3.6.0 fast-logger-3.0.2-A9Bswy2GVUsKAHoz8fvrlL
    http-types-0.12.3-9d6q1lRkXJ82WkEPNqln4g
    http2-2.0.5-BllHExNi1IH8HlF0Idpmkf
    iproute-1.7.10-AmhT7ZN3o7u683m3Ott0am
    network-3.1.2.0-5sobkliwwmD9npzHIw7lyx
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    resourcet-1.2.4.2-BZsuII1Oa0W8Dk1G7U9UBs
    streaming-commons-0.2.2.1-ITJbuSBZjcj9a86hqzL4VG text-1.2.3.2
    time-1.9.3 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
    vault-0.3.1.4-AWUFIAXOzve6dyCXPnhCFu
    void-0.7.3-FJLCa6y31Qt20kSi8TCcBC
    wai-3.2.2.1-6oI1VVe1KBYB1dop6PmYGX
    wai-logger-2.3.6-LnHG2wjv4xTDTZ2H3IdmTa
    word8-0.1.3-724fxDOkAtI9odHi3S4RPp
    zlib-0.6.2.2-85jZF5E8OnCKweDgfCRJUx

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.1.4.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-extra
version:              3.1.4.1
visibility:           public
id:                   wai-extra-3.1.4.1-31fMA1t7lu1BbYjCk0Nk9J
key:                  wai-extra-3.1.4.1-31fMA1t7lu1BbYjCk0Nk9J
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  77ed5961d68e8a630e7c5d81428f35eb
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:       Network.Wai.Middleware.RequestLogger.Internal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/wai-extra-3.1.4.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/wai-extra-3.1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/wai-extra-3.1.4.1
hs-libraries:         HSwai-extra-3.1.4.1-31fMA1t7lu1BbYjCk0Nk9J
depends:
    HUnit-1.6.1.0-Al9f3Qej7gDJKc5vvTRGN1
    aeson-1.5.4.1-7Fmt2H1B65wDOTuTXG6T4t
    ansi-terminal-0.11-LOtSOdyRo4jIdt6YEKBVwC base-4.14.1.0
    base64-bytestring-1.2.0.1-AWZILofJAf294n139sG5uA
    bytestring-0.10.10.0 call-stack-0.2.0-24ucAmGZmofHK6SkzuNcAo
    case-insensitive-1.2.1.0-7Aj4g2iZgZR4Q8sB4UJ8do containers-0.6.2.1
    cookie-0.4.5-9B2dS5wCPmq3hZq3aUzZ9g
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 deepseq-1.4.4.0
    directory-1.3.6.0 fast-logger-3.0.2-JUP3Fn3ppqUEJqBZ6pRT5y
    http-types-0.12.3-Enc01lXxE6zKAvrRk5fVtF
    http2-2.0.5-CqnDFgy1zUQC6FqwUrxTW2
    iproute-1.7.10-JsJLbe1eT3T3OkgNLHxctG
    network-3.1.2.1-5n59R95rYCJBWJCbaUzri2
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    resourcet-1.2.4.2-aAUHIMBSjwCNW9oIrhP8L
    streaming-commons-0.2.2.1-HBqljEjlrAHzdoSZyuXH6 text-1.2.3.2
    time-1.9.3 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
    vault-0.3.1.4-JpfGL3QLjkt9F7kn0czFBF
    void-0.7.3-FJLCa6y31Qt20kSi8TCcBC
    wai-3.2.2.1-JGrlPhrCmGNA1e9qQHNbG7
    wai-logger-2.3.6-6z4R1i4nqEg9hyY2NvRIzy
    word8-0.1.3-724fxDOkAtI9odHi3S4RPp
    zlib-0.6.2.2-85jZF5E8OnCKweDgfCRJUx

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
